From eeb7ac9294dae69f6110c8b5f1c136be118a6110 Mon Sep 17 00:00:00 2001
From: kk2000 <kk2000@cea.fr>
Date: Wed, 31 Jul 2019 18:38:41 +0200
Subject: [PATCH] Adding native support for the Gibiane language
 (http://www-cast3m.cea.fr)

---
 ctags/Makefile.am                 |   3 +-
 ctags/main/parsers.h              |   3 +-
 ctags/parsers/GIBIANE.c           | 353 +++++++++++++++++++++++++++++++++++
 data/Makefile.am                  |   6 +-
 data/filedefs/filetypes.gibiane   |  65 +++++++
 data/filetype_extensions.conf     |   1 +
 data/tags/std.dgibi.tags          | 312 +++++++++++++++++++++++++++++++
 scintilla/Makefile.am             |   3 +-
 scintilla/include/SciLexer.h      |  14 ++
 scintilla/include/Scintilla.iface |  18 +-
 scintilla/lexers/LexGIBIANE.cxx   | 376 ++++++++++++++++++++++++++++++++++++++
 scintilla/src/Catalogue.cxx       |   1 +
 scripts/create_dgibi_tags.sh      |  32 ++++
 src/editor.c                      |  24 +++
 src/filetypes.c                   |   1 +
 src/filetypes.h                   |   1 +
 src/highlighting.c                |   6 +
 src/highlightingmappings.h        |  32 ++++
 src/symbols.c                     |   2 +-
 src/tagmanager/tm_parser.c        |   5 +
 src/tagmanager/tm_parser.h        |   1 +
 src/tagmanager/tm_workspace.c     |   7 +-
 src/tagmanager/tm_workspace.h     |   2 +-
 23 files changed, 1258 insertions(+), 10 deletions(-)
 create mode 100644 ctags/parsers/GIBIANE.c
 create mode 100644 data/filedefs/filetypes.gibiane
 create mode 100644 data/tags/std.dgibi.tags
 create mode 100644 scintilla/lexers/LexGIBIANE.cxx
 create mode 100755 scripts/create_dgibi_tags.sh

diff --git a/ctags/Makefile.am b/ctags/Makefile.am
index 3b4e191b..b8ac7d6e 100644
--- a/ctags/Makefile.am
+++ b/ctags/Makefile.am
@@ -50,7 +50,8 @@ parsers = \
 	parsers/tex.c \
 	parsers/txt2tags.c \
 	parsers/verilog.c \
-	parsers/vhdl.c
+	parsers/vhdl.c \
+	parsers/GIBIANE.c
 
 libctags_la_SOURCES = \
 	main/args.c \
diff --git a/ctags/main/parsers.h b/ctags/main/parsers.h
index b261f80e..25b9e7bb 100644
--- a/ctags/main/parsers.h
+++ b/ctags/main/parsers.h
@@ -65,6 +65,7 @@
 	GoParser, \
 	JsonParser, \
 	ZephirParser, \
-	PowerShellParser
+	PowerShellParser, \
+	GIBIANEParser
 
 #endif  /* CTAGS_MAIN_PARSERS_H */
diff --git a/ctags/parsers/GIBIANE.c b/ctags/parsers/GIBIANE.c
new file mode 100644
index 00000000..7683a754
--- /dev/null
+++ b/ctags/parsers/GIBIANE.c
@@ -0,0 +1,353 @@
+/*
+*   This source code is released for free distribution under the terms of the
+*   GNU General Public License.
+*
+*   This module contains code for generating tags for GIBIANE scripts.
+*   Copyright 2019 Thibault Lindecker (Communication & Systemes) - thibault.lindecker@c-s.fr
+*/
+
+/*
+*   INCLUDE FILES
+*/
+#include "general.h"  /* must always come first */
+#include "debug.h"
+#include "main.h"
+#include "parse.h"
+#include "read.h"
+#include "vstring.h"
+#include "keyword.h"
+#include "entry.h"
+#include "routines.h"
+#include <string.h>
+
+typedef enum {
+  K_PROCEDURE,
+  K_VARIABLE,
+  COUNT_KIND
+} GIBIANEKind;
+
+static kindDefinition GIBIANEKinds[COUNT_KIND] = {
+    { true, 'p', "procedure",  "procedures" },
+    { true, 'v', "variable" ,  "variables"  }
+};
+
+typedef enum eGIBIANELineType {
+  LTYPE_UNDETERMINED,
+  LTYPE_COMMENT
+} lineType;
+
+
+typedef enum eTokenType {
+    TOKEN_UNDEFINED,
+    TOKEN_IDENTIFIER,
+    TOKEN_EOF,
+    TOKEN_SEMICOLON,
+    TOKEN_PROCEDURE,
+    TOKEN_PROCEDURE_FIN,
+    TOKEN_VARIABLE,
+    TOKEN_INSTRUCTION
+} tokenType;
+
+typedef struct {
+  tokenType       type;
+  vString *       string;
+  unsigned long   lineNumber;
+  MIOPos          filePosition;
+} tokenInfo;
+
+static void initGIBIANEEntry (tagEntryInfo *const e, const tokenInfo *const token,
+                 const GIBIANEKind kind)
+{
+  initTagEntry (e, vStringValue (token->string), kind);
+  e->lineNumber = token->lineNumber;
+  e->filePosition = token->filePosition;
+}
+
+static void makeTag (const tokenInfo *const token, const vString *const arglist, const vString *const returnlist,
+                  const GIBIANEKind kind)
+{
+
+  if (GIBIANEKinds[kind].enabled)
+  {
+    tagEntryInfo e;
+
+    initGIBIANEEntry (&e, token, kind);
+
+    if (arglist)
+      e.extensionFields.signature = vStringValue (arglist);  //Ce que mange la procedure
+    if (returnlist)
+      e.extensionFields.varType   = vStringValue (returnlist);
+
+    makeTagEntry (&e);
+  }
+
+}
+
+static tokenInfo *newToken (void)
+{
+  tokenInfo *const token = xMalloc (1, tokenInfo);
+  token->type            = TOKEN_UNDEFINED;
+  token->string          = vStringNew ();
+  token->lineNumber      = getInputLineNumber ();
+  token->filePosition    = getInputFilePosition ();
+  return token;
+}
+
+static void deleteToken (tokenInfo *const token)
+{
+  vStringDelete (token->string);
+  eFree (token);
+}
+
+static void copyToken (tokenInfo *const dest, const tokenInfo *const src)
+{
+  dest->lineNumber   = src->lineNumber;
+  dest->filePosition = src->filePosition;
+  dest->type         = src->type;
+  vStringCopy (dest->string, src->string);
+}
+
+static bool isIdentChar (const int c)
+{
+  return (isalnum (c) || c == ':' || c == '_' || c == '-' ||
+                         c >= 0x80 || c == '.' || c == ' ');
+}
+
+static bool isSpace (int c)
+{
+  return (c == '\t' || c == ' ' || c == '\v' ||
+                       c == '\r' || c == '\f');
+}
+
+static bool isQuote (int c)
+{
+  return (c == '\'');
+}
+
+static void parseIdentifier (vString *const string, const int firstChar)
+{
+  if(firstChar == '='){ //parse variable
+    vStringPut (string, (char) firstChar); return;
+  }
+
+  int c = firstChar;
+  do
+  {
+    vStringPut (string, (char) c);
+    c = getcFromInputFile ();
+  } while (isIdentChar(c) && c != ';' && c != '=' && !isQuote(c) && c != EOF);
+
+  ungetcToInputFile (c);
+}
+
+static int skipSpaceQuote (int c)
+{
+  while(isSpace(c) || isQuote(c))
+    c = getcFromInputFile ();
+  return c;
+}
+
+static void readToken (tokenInfo *const token)
+{
+  int c;
+  static bool newline = false;
+  static bool comment_line = false;
+  static bool debut_proc = false;
+
+  token->type   = TOKEN_UNDEFINED;
+  vStringClear (token->string);
+
+  c = getcFromInputFile ();
+  c = skipSpaceQuote (c);
+
+  /* we ignore comments line (start with '*') */
+  if(newline && c != '*'){
+    newline = false;
+  }
+
+  if(c == '\n'){
+    newline = true;
+  }
+  else if(c == '*' && newline){
+    comment_line = true;
+    while(comment_line){
+      comment_line = false;
+      do
+      {
+        c = getcFromInputFile ();
+      } while (c != '\n' && c != EOF);
+      if(c == '*'){
+        comment_line = true;
+      }
+    }
+  }
+  else if(c == ';'){
+    vStringPut (token->string, (char) c);
+    token->type = TOKEN_SEMICOLON;
+    debut_proc = false;
+  }
+  else if(c == EOF){
+    token->type = TOKEN_EOF; /*End of file */
+  }
+  else{
+    vString *find_variable = vStringNew ();
+    vString *find_procedure = vStringNew ();
+    vString *find_instruction = vStringNew ();
+    while(1)
+    {
+      vStringPut (find_variable, (char) c);
+      vStringPut (find_procedure, (char) c);
+      vStringPut (find_instruction, (char) c);
+
+      c = getcFromInputFile ();
+      if(c == '='){
+        vStringCat(token->string, find_variable);
+        token->type = TOKEN_VARIABLE;
+        break;
+      }
+
+      /* In GIBIANE, the first 4 letters are enough to call an operator, but user can specify more than 4 letters.
+       * Exemple : for calling 'DEBPROC' operator, user can use : DEBP, DEBPR, DEBPRO and DEBPROC. */
+      int keyword_min_size = ((int)find_procedure->length < 4) ? 4 : (int)find_procedure->length;
+
+      if(strncasecmp (vStringValue (find_procedure), "DEBPROC", keyword_min_size) == 0){
+        if(isQuote(c) || c == ' '){
+          vStringCat(token->string, find_procedure);
+          token->type = TOKEN_PROCEDURE;
+          debut_proc = true;
+          break;
+        }
+      }else if(strncasecmp (vStringValue (find_procedure), "FINPROC", keyword_min_size) == 0){
+        if(isQuote(c) || c == ' ' || c == ';'){
+          vStringCat(token->string, find_procedure);
+          token->type = TOKEN_PROCEDURE_FIN;
+          break;
+        }
+      }
+
+      if(isQuote(c) || c == ' '){
+        vStringClear (find_procedure);
+      }
+
+      if((!isIdentChar(c) || c == ';' || c == EOF || c == '\n' || (debut_proc && c == ' ')) && !isQuote(c)){
+        vStringCat(token->string, find_instruction);
+        token->type = TOKEN_INSTRUCTION;
+        break;
+      }
+    }
+    ungetcToInputFile (c);
+    token->lineNumber   = getInputLineNumber ();
+    token->filePosition = getInputFilePosition ();
+
+  }
+
+}
+
+/* We enter here because we have detected 'DEBPROC' operator in readToken().
+ * We will read the name of the procedur, its arguments and its return values :
+ * Exemple :
+ *    DEBPROC myprocedure toto*'TABL';
+ *      do something
+ *    FINPROC titi*'MOTS' tata*'ENTIER'
+ * For this example, we would have :
+ *  name : myprocedure
+ *  arguments : toto*'TABL'
+ *  return values : titi*'MOTS' tata*'ENTIER' */
+static void parseProcedure (tokenInfo *const token)
+{
+  tokenInfo *nameFree = NULL;
+  bool nextline = false;
+  bool finproc  = false;
+  vString *returnlist = vStringNew ();
+  vString *procedur_name = vStringNew ();
+  vString *arglist = vStringNew ();
+  vString *espace = vStringNewInit (" ");
+  vString *egal = vStringNewInit ("=");
+
+  /* We read the name of the procedur */
+  readToken (token);
+  nameFree = newToken ();
+  copyToken (nameFree, token);
+
+  do
+  {
+    readToken (token);
+
+    if(token->type == TOKEN_SEMICOLON){
+      nextline = true;
+      if(finproc == true)
+        break;
+    }
+    /* arguments of the procedur */
+    if(nextline == false){
+      vStringCat (arglist, token->string);
+      vStringCat (arglist, espace);
+    }
+    /* return values of the procedur */
+    if(finproc == true){
+      vStringCat (returnlist, token->string);
+      vStringCat (returnlist, espace);
+    }
+    if(token->type == TOKEN_PROCEDURE_FIN)
+      finproc = true;
+
+  }
+  while (token->type != TOKEN_EOF);
+
+  if(returnlist->length > 0){
+    vStringCat (returnlist, egal);
+  }
+
+  /* We make tag */
+  makeTag(nameFree, arglist, returnlist, K_PROCEDURE);
+}
+
+/* We enter here because we have detected '=' char in readToken().
+ * Because we are just after the '=' char, we have already read the variable name. */
+static void parseVariable (tokenInfo *const token)
+{
+  /* Make a copy of the token */
+  tokenInfo *nameFree = NULL;
+  nameFree = newToken ();
+  copyToken (nameFree, token);
+
+  /* We make tag */
+  makeTag(nameFree, NULL, NULL, K_VARIABLE);
+
+  deleteToken (nameFree);
+}
+
+/* main loop on the GIBIANE language file */
+static void findGIBIANETags (void)
+{
+  tokenInfo *const token = newToken ();
+  readToken (token);
+  while (token->type != TOKEN_EOF)
+  {
+    switch (token->type)
+    {
+      case TOKEN_PROCEDURE:
+        parseProcedure (token);
+        break;
+
+      case TOKEN_VARIABLE:
+        parseVariable (token);
+        break;
+
+      default: break;
+    }
+    readToken (token);
+  }
+  deleteToken (token);
+}
+
+extern parserDefinition* GIBIANEParser (void)
+{
+  static const char *const extensions [] = { "dgibi", "procedur", NULL };
+  parserDefinition* def                  = parserNew ("GIBIANE");
+  def->kindTable                         = GIBIANEKinds;
+  def->kindCount                         = ARRAY_SIZE (GIBIANEKinds);
+  def->extensions                        = extensions;
+  def->parser                            = findGIBIANETags;
+  return def;
+}
diff --git a/data/Makefile.am b/data/Makefile.am
index 04dead33..8faa6995 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -74,14 +74,16 @@ filetypes = \
 	filedefs/filetypes.vhdl \
 	filedefs/filetypes.xml \
 	filedefs/filetypes.yaml \
-	filedefs/filetypes.zephir
+	filedefs/filetypes.zephir \
+	filedefs/filetypes.gibiane
 
 tagfiles = \
 	tags/std99.c.tags \
 	tags/std.php.tags \
 	tags/std.py.tags \
 	tags/std.pas.tags \
-	tags/entities.html.tags
+	tags/entities.html.tags \
+	tags/std.dgibi.tags
 
 template_files = \
 	templates/files/file.html \
diff --git a/data/filedefs/filetypes.gibiane b/data/filedefs/filetypes.gibiane
new file mode 100644
index 00000000..136d8348
--- /dev/null
+++ b/data/filedefs/filetypes.gibiane
@@ -0,0 +1,65 @@
+# For complete documentation of this file, please see Geany's main documentation
+[styling]
+# Edit these in the colorscheme .conf file instead
+default=default
+comment=comment
+string=string
+number=number_1
+table=class
+
+# README :
+
+#1) Ce qui suit (keyword_1, function, operator, etc.) est definit dans "data/filedefs/filetypes.common"
+#       ou dans les fichiers de colorations speciaux (data/colorshemes/*.conf)
+
+#2) La meme syntaxe doit etre reprise dans "scintilla/include/SciLexer.h" et dans "src/highlightingmappings.h"
+
+#3) C'est dans "scintilla/lexers/LexGIBIANE.cxx", que l'on dit que :
+#       keywords1 <=> word => coloration keyword_1 definit dans filetypes.common ou .conf
+#       keywords2 <=> word2 => coloration keyword_2 definit dans filetypes.common ou .conf
+#       keywords3 <=> word3 => coloration backticks definit dans filetypes.common ou .conf
+#       keywords4 <=> word4 => coloration function definit dans filetypes.common ou .conf
+#       ...
+
+word=keyword_1
+word2=keyword_2
+word3=keyword_1
+word4=function
+word5=keyword_3
+word6=function
+word7=function
+word8=operator
+
+
+[keywords]
+# all items must be in one line and in lowercase
+conditional=si sinon sino finsi fins
+test1=cos cosh acos acoh sin sinh asin asih tan tanh atg atah erf exp factorie fonc log mini maxi enti entier flot flottant sign signe alea abs
+loop=repe repet repete repeter quit iter itere iterer fin
+task=debp debpr debpro debproc finp finpr finpro finproc debm debme debmet debmeth finm finme finmet finmeth
+element=poi1 seg2 seg3 tri3 tri4 tri6 tri7 qua4 qua5 qua8 qua9 rac2 rac3 cub8 cu20 pri6 pr15 lia3 lia4 lia6 lia8 mult tet4 te10 pyr5 py13 atta supe rap3 lip6 lip8 poly cu27 pr21 te15 py19 seg4 qu16 tr12 pr18 seg6 tr21 qu36 c216 p126 te56 py91 sure
+function1=@A1DDL accdchi1 accdchi2 accevite acier acti3 @afevozt affiche aft1 aft2 aft ajuste @algsta @ana_lim analyser anime animgks anlimtre annoimp arcgau @arr asparam autopilo balourd bif bili_efz bili_moy biovol boa boite broche bruche @b_tpo2d calactiv calcdisp calcp calctrac calculer callm calmu campbell @carene @cartoon ccdonchi @cdg @CFD10 @CFS10 ch2clim chamint chanolii chanuobj chanvcom chanvesp chanvsos charther @CHCOTAE chdclim @chflec chitrnsp @CHREP chtgau ch_theta ch_thetx chtitr cinema cinemb cinimod @circons @clch @cldhc @cldh @clim clinc @clmi1c @clmi2c @clpc @clpd codenorm coller1 coller2 coller con_calc condens continu contseg3 convt coq2mas @corigi corman cormasse @couplan @couple coupler cour3d courspec @coutor1 @coutor2 creer_3d @cripl critloc ctod darcysat darcytra ddfour deadfonc deadjaco deadktan deadresi deadutil deconv3D deconv dedans deduadap @deduire @defa2dl @defa2dp @defpl depou descour @deslis destra diffanis donchi1 donchi2 drexus dupont2 dynamic dynamod2 dynamod3 dynamode ec8acsis effmarti elecneut @enca enceinte enermode enrichis epaifut @EVN_IDT @EVN_MNG exac @excel1 exec execrxt exic explorer factorie fcourant fdens fiabili filc filtreke finvrepa @FIS_1 @FIS_2 @FIS_3DS @FIS_3 fixhc @fix flambage floquet forbloc for_cont fornod four2tri fpal frctrace @frenet frepart freqperi fronabs f_s2pi ftran gam1 @gattpar g_calcul gdflim1 @global gresp g_theta1 g_theta g_ulti2D g_ultifr hasofer hauban hbm_post hbm h_b @helice @HISTOGR hrayo hrcav htc_chbw htc_per htctran htc_wtr htc_www ht_pro idbht identi images impchi1 impchi2 @inclusi indibeta indiobje inductio inichi1 inichi2 inichimi inimur ininlin initEFMH @initia initou
+function2=initVF in_mini int_comp @INTLIN @isosurf issleq jeu @keff kepsilon kresp kr_pro kuet kweib1 @lacalc @lacrit @lafail @lagraph @lakappa @lalist @lamass @lamat @laread @larig @lasiep @laverg @lavis lch2clim lch2delp lch2eps lch2fion lch2iaff lch2impr lch2itma lch2itso lch2logc lch2mdel lch2nfi lch2nite lch2nty4 lch2prep lch2sort lch2temp lch2tot lespcomp lespityp lesplogk lespstoe libdd lichxmx licochar licomnom liespece liliden liliech limemeca linbiden linvcomp @lireent lireflot @lireris lirsoso @LISPA16 @lisse litemper lsosfrac lsossoli mag_nlin mailstru mailvoro @MATETHM mayoto m_dampin m_damp_K mdnris mdrecomb @mesu @mistpar @mod @MODTRI montagne moyespec mrcfram1 mrcfram2 mrcfram3 mrcfram4 mrcframe mrcshell mrctrace mulc multidec multirec @m_voro nataf newmark nocomchi noespchi normalim norv1 nsclim orbite @ortho @otcoque @otpout ouvfiss parastat parmchi2 pasapas pas_defa pas_epth pas_etat pas_helm @pashist pas_init pas_mate pas_rayo pas_repr pas_resu pas_verm @p_boit2 @PCPT peche pencechi pfluage phasage @plotpri pmpb pointcyl @pointir pointsph @polo polyno @pomi postddi1 postddi postou postvibr pot_scal pot_vect pout2mas ppre @PRCA1 @PRCA2 @PRCA3 @PRCA4 @PRCA5 prepaenc probabrs probdens prochext prodt projgril propag psatt @p_voro quadratu ramberg @rayo ray @rccmco2 @rccm @rccmtrv rdiv recentre recompom recompos @relief @rempcou @rempfat @rempgro repart @repere repix reseau reso_asy respowns respowsp retrait retsat rosent rota_imp rvsat rvst2 @SATURAT satutils sge shfdt sif signcorr signderi signenve signsynt @sigref silam sissib solvEFMH solvVF SPAL spplanc @statio @stat @stbl @syslin TABLO2D TABLO3D takm_efz takm_moy tension @test thermic t_ipol @tole2 @tole3 topochan topocrit topofilt topomate topoptim toporstr toposauv toposurf @toro @total t_piteta trac3d_2 trac3d trachis trachit tracmeca tracpart tractufi traduire trangeol transfer transgen transit0 transit1 transit2 transit3 translin transnon trc trtrajec unilater unpas updaEFMH updaVF valnom valspe vapdif varihc varihcsu @vecoul vertytab @vis3d @visor vitetfor viteunil vnimp vtimp weibull xbif @zacplus @zacpro1 @zacpro2 @zacpro3 @zacpro4 @zacpro5 @zacpro6 @zacpro7 @zacpro8 zigzag zonfis
+operator=opti fin born dens droi lapl cerc mota quel inte para souc et poin plus moin tran rota trac inve cote elem cont diff chan list surf conf info tour homo affi syme incl elim titr racc tass sort lire bary dall orie manu oubl comp cout pave comm noeu mot nbel nbno noti face coor norm temp volu lect sauf prog + - * / ** flot enti log exp depl psca pvec pmix liai regl hook sols reso date rigi bloq depi hota stru text proj venv elst jonc reco mass clst sigm rela forc mome vloc base dime extr vers vibr maxi xtmx ytmx < eg <eg ou ega non neg mult pjba crit diag xtx uniq bsig deda max1 mots repe quit si sino fins ipol abs sin cos atg enve isov detr enle remp inse coli tria tabl redu symt anti resu pres exco nomc saut defo appu inva prin vmis ksig sign suit valp ordo tire rege dess amor char coul chpo afco evol orth thet comb deve vect pica capi/ data mdir2/copi dimn sauv rest cara mate gene capa elfe jaco plas gree mode finp xty debp ktan form mess nnor cubp cubt cer3 fdt seis ener epsi intg cour reac supe zero depb exci kp acti elas erre cong lump obte vari modi masq exis mini grad ense ifre dfou sigs mapp somm brui rten dspr tfr tote graf tres type osci spo inde chsp tagr perm cabl fofi work qulx debi cmoy comt cond flux rimp filt tfri conc iter acqu sour conv acoh psmo asih ecou mena synt argu atah dyne fonc resp plac vale proi exce aret calp indi act3 biot dedu conn nloc chai cosi cvol diad hann insi lsqf ltl pert prns psrs siar spon visa cneq ccon mesu pile simp util menu cosh sinh tanh deg3 aide racp refe ksof veri nske kmab noel doma fpu gmv eqpr eqex vibc avct kdia kmtp kmf mdia dfdt tcrr tcnm sqtp somt nlin cmct kcht lapn raft klop kres cson fimp/ data mdir3/nuag weip khis kops fsur flam elno dbit ns toim fimp kmbt kbbt dudw frot tsca konv kcha mhyb matp hdeb hvit hybp smtp divu mocu chau tail erf sens impo dans impf ntab fron fuit epth fpt kfpt fpa kfpa echi qond kpro ffor raye rayn vsur traj aju1 aju2 frig excf nomm prec erfc onde cfl dedo dcov parc pola chi1 chi2 pent pret meth xxt cblo genj zleg mesm fion neut logk coac resi mutu sore diri lign obje debm finm heri deco exte dmmu dmtd bmtd ssch mrem assi fiss prim annu prob sais choi deto part clmi pmat excp prop phaj alea gnfl mpro sste adve bgmo ecfe coup verm dfer gyro cori kent fant itrc reto ijet impe moca levm ravc idli raff cfnd adet psip acos asin tan trie gane hist etg oter xfem rfco vide voro prra posi mise misl coll pod
+
+[settings]
+# default extension used when saving files
+extension=dgibi
+comment_single=*
+
+# set to false if a comment character/string should start at column 0 of a line, true uses any
+# indentation of the line, e.g. setting to true causes the following on pressing CTRL+d
+  #command_example();
+# setting to false would generate this
+# command_example();
+# This setting works only for single line comments
+comment_use_indent=false
+
+# context action command (please see Geany's main documentation for details)
+context_action_cmd=
+
+[build_settings]
+# %f will be replaced by the complete filename
+# %e will be replaced by the filename without extension
+# (use only one of it at one time)
+run_cmd=castem19 "%f"
diff --git a/data/filetype_extensions.conf b/data/filetype_extensions.conf
index 4f0d309f..69149eaf 100644
--- a/data/filetype_extensions.conf
+++ b/data/filetype_extensions.conf
@@ -73,6 +73,7 @@ VHDL=*.vhd;*.vhdl;
 XML=*.xml;*.sgml;*.xsl;*.xslt;*.xsd;*.xhtml;*.xul;*.dtd;*.xtpl;*.mml;*.mathml;
 YAML=*.yaml;*.yml;
 Zephir=*.zep;
+GIBIANE=*.dgibi;*.procedur;
 None=*;
 
 # Note: restarting is required after editing groups
diff --git a/data/tags/std.dgibi.tags b/data/tags/std.dgibi.tags
new file mode 100644
index 00000000..3e3ac295
--- /dev/null
+++ b/data/tags/std.dgibi.tags
@@ -0,0 +1,312 @@
+format=tagmanager
+@A1DDL16TABDYN * TABLE 0=
+@AFEVOZT160=
+@ALGSTA16i *ENTIER ttt *TABLE 0ttt =
+@ANA_LIM16PRECED * TABLE 0PRECED =
+@ARR16x * FLOTTANT n * ENTIER Indic / MOT 0r =
+@CARENE16COU * TABLE ROT_1 * LISTREEL ROT_2 * LISTREEL N_COU * FLOTTANT AXE_P * ENTIER 0CARE_1 LIS COUI =
+@CARTOON16TAB1 *TABLE MAILL1 *MAILLAGE BL1 /RIGIDITE OEIL /POINT AMPLI /FLOTTANT OSCILLE /MOT 0DEF1 =
+@CFD1016FO1 * FLOTTANT 0=
+@CFS1016FO1 * FLOTTANT 0=
+@CHFLEC16ECH1 * FLOTTANT CHPO1 * CHPOINT ARG1 / MOT TAIL1 / FLOTTANT 0PTF1 =
+@CIRCONS160=
+@CLDHC16MAIL0 *MAILLAGE CONT0 *TABLE 0RIGCLP FCLP0 =
+@CLMI1C16MAIL0 *MAILLAGE CONT0 *TABLE 0RIGCLP FCLP0 =
+@CLMI2C16MAIL0 *MAILLAGE CONT0 *TABLE 0RIGCLP FCLP0 =
+@CLPD16MAIL0 *MAILLAGE DEF0 *TABLE 0RIGCLP DEPTOT =
+@COUTOR116IEL *MAILLAGE CHT *CHPOINT CHN *CHPOINT CHB *CHPOINT 0DS2 R T ALPHA BETA =
+@COUTOR216GEOFRE *MAILLAGE CHT *CHPOINT CHN *CHPOINT CHB *CHPOINT 0CHRT =
+@CRIPL16MOD *MMODEL SIG *MCHAML VAR *MCHAML MAT *MCHAML ER *FLOTTANT 0CRIPL =
+@DEFA2DL16LIG0 * MAILLAGE PIN1 * POINT TAI1 * FLOTTANT TYP1 * MOT DES1 / MOT LOG1 / LOGIQUE 0MAT1 =
+@DEFA2DP16TAI1 * FLOTTANT ORI1 * POINT VEC1 * POINT TYP1 * MOT 0MAI1 =
+@DEFPL16MMM *MMODEL MOD *TABLE MAT *MCHAML EPS *MCHAML SIGI *MCHAML EPSP *MCHAML VAR *MCHAML ERR *FLOTTANT E23D *MCHAML V23D *MCHAML 0N_VAR N_EPSP E23D V23D =
+@ENCA16TAIL1 * FLOTTANT MAIL1 * MAILLAGE VEC1 * POINT 0PTF1 =
+@EVN_IDT16T1 * TABLE ID_BU * ENTIER 0T1 =
+@EVN_MNG16T1 * TABLE ID_BU * ENTIER 0T1 =
+@FIS_116tab1 *table tab2 *table 0tab2 =
+@FIS_216p01 *point p03 *point p05 *point p07 *point oc *point c *FLOTTANT a *FLOTTANT alpha *FLOTTANT beta *FLOTTANT nt *entier ndt *entier 0vtot alpha_mi alpha_ma lsommet1 lsommet3 lsommet5 lsommet7 =
+@FIS_3DS16c *flottant a *flottant lo *flottant to *flottant ho *flottant nt *entier nc *entier ns *entier rc0 *flottant rc1 *flottant rc2 *flottant rc3 *flottant alpha *flottant ndt *entier nsdt *entier xl *entier xt *entier xh *entier 0vtot lff levreinf sar slat sinf sav_s ssup_s slat_s boudin ep3 =
+@FIX16x * FLOTTANT n * ENTIER Indic / MOT 0r =
+@GATTPAR16fichier * MOT 0MATAB =
+@GLOBAL16TAB1 *TABLE BLO1 *RIGIDITE COURB2 *EVOLUTION MOEFF *MOT 0EVOL1 =
+@HELICE16P1 /POINT GEO1 /MAILLAGE TYP1 *MOT P0 *POINT V0 *POINT PAS *FLOTTANT ALPHA *FLOTTANT NP *ENTIER 0GEO2 GEO3 =
+@HISTOGR16LVAL1 * LISTREEL TOPT1 / TABLE LSOR1 / LOGIQUE 0=
+@INCLUSI16THO7U * TABLE DPAR1 * FLOTTANT DREP1 * FLOTTANT 0TMPARMAT =
+@INITIA16ttt *TABLE 0ttt =
+@INTLIN16LI1 * LISTREEL LI2 * LISTREEL X0 * FLOTTANT 0=
+@ISOSURF16MASSIF0 * MAILLAGE LIS1 * LISTREEL HANA1 * CHPOINT 0MAIF1 CHPF1 =
+@KEFF16MOD1 *MMODEL MAT1 *MCHAML CLIM1 *PROCEDUR AMPL1 *FLOTTANT CONV1 *ENTIER VISU1 *TABLE 0K C D =
+@LACRIT16TT1 *TABLE NZON *ENTIER TSIEP *TABLE FM *FLOTTANT MCRIT *MOT 0TLISP =
+@LAREAD16TCOMP *TABLE NUNIT /ENTIER NOM_FILE /MOT 0=
+@LAVERG16TAB1 *TABLE NPLY *ENTIER OEIL1 *POINT 0=
+@LAVIS16TCOMP *TABLE NZONE *ENTIER 0=
+@LIREENT16UMIN *ENTIER UMAX *ENTIER 0FL =
+@LIRERIS160BO =
+@LISPA1616CHARG *TABLE DON *TABLE 0DON =
+@LISSE16EVO_1 * EVOLUTION FLO_1 * FLOTTANT FLO_2 * FLOTTANT ENT_1 * ENTIER ENT_2 * ENTIER 0EVO_2 =
+@MISTPAR16fichier * MOT SENSIP1 * ENTIER SENSIP2 * ENTIER 0PDILT E1 E2 E3 NU12 NU23 NU13 MU12 MU23 MU13 PNBRE PCOHI PECOU PEDIR PRVCE PECRX PDVDI PCROI PINCR =
+@MOD16I J 0MOD =
+@MODTRI16TABPARA * TABLE DATA * TABLE 0=
+@M_VORO160=
+@ORTHO16MAIL1 * MAILLAGE LIG1 * MAILLAGE CH1 * CHPOINT CH2 * CHPOINT ALPHA * FLOTTANT LL * LISTREEL TYPEMOD / MOT TYPEELT / MOT PTGENE / POINT 0MATGEO MODL1 =
+@OTCOQUE16CRIT *FLOTTANT NMIT *ENTIER SPEI *FLOTTANT VLIM *FLOTTANT STEC *FLOTTANT TMOD *TABLE TMAT *TABLE FORZE *CHPOINT VINCO *RIGIDITE PV *POINT 0SPZO DE1 =
+@OTPOUT16CRIT *FLOTTANT NMIT *ENTIER SEZY *FLOTTANT SEZZ *FLOTTANT SLIM *FLOTTANT STEC *FLOTTANT TMOD *TABLE TMAT *TABLE FORZ *CHPOINT VINCO *RIGIDITE TVECT *TABLE 0TTRA SPOT =
+@POINTIR160=
+@POLO16TAGEO1 * TABLE TABOB1 * TABLE PL1 / TABLE 0TABCHB TAB2 =
+@PRCA116T1 * TABLE ID_BU * ENTIER 0T1 =
+@PRCA516T1 * TABLE ID_BU * ENTIER 0T1 =
+@P_BOIT2160=
+@RAYO16PF *POINT P1 *POINT NBC *ENTIER 0ST SINT L1EXT L2EXT L3EXT L4EXT LLD LLG =
+@RCCM16TABCOUP *TABLE TABET *TABLE TABGROU /TABLE TABFATI /TABLE 0=
+@RCCMCO216NNE *ENTIER NNC *ENTIER PP1 *POINT PP2 *POINT NSEG *ENTIER SIG1 *MCHAML MOD1 *MMODEL EPAI *FLOTTANT GRAPL *LOGIQUE ECRI *LOGIQUE NOM *MOT PP3 *POINT 0TABV =
+@REMPCOU16TABCOUP *TABLE P1 *POINT P2 *POINT NC *ENTIER MODELT *MMODEL EPAI *FLOTTANT GRAP *MOT ECR *MOT NOM /MOT VTRA /POINT 0=
+@REPERE16ORI1 / POINT TAI0 / LISTREEL NOM1 / LOGIQUE COU1 / MOT 0RP1 =
+@SIGREF16P *MCHAML M *MCHAML W *MCHAML A *MCHAML MO *MMODEL 0SS =
+@STATIO16ttt *TABLE 0=
+@STBL16CHOZ * TABLE 0SORTZ =
+@SYSLIN16K1 *TABLE F1 *TABLE 0U1 =
+@TEST16EPS1 *MCHAML EPS2 *MCHAML ERR *FLOTTANT 0TEST =
+@TOLE216L_1 * MAILLAGE RA_1 * FLOTTANT N_1 * ENTIER 0RE_1 =
+@TOLE316A_1 * MAILLAGE A_2 * MAILLAGE RA_1 * FLOTTANT N_1 * ENTIER 0C_1 C_2 S_1 S_2 V_1 =
+@TORO16TAGEO *TABLE TABOB *TABLE 0tabchb tab2 =
+@ZACPRO216S1 * MCHAML S2 * MCHAML S3 * MCHAML S4 * MCHAML S5 * MCHAML S6 * MCHAML MO * MMODEL 0SIGMAA =
+@ZACPRO316CC * MCHAML 0EP1 EP2 EP3 EP4 EP5 EP6 =
+@ZACPRO416BB * MCHAML 0CO1 CO2 CO3 CO4 CO5 CO6 =
+@ZACPRO516CO * MCHAML MO * MMODEL 0DEVAA =
+@ZACPRO616X * MCHAML Y * MCHAML 0PRSC =
+@ZACPRO716AA * MCHAML 0VMISAA =
+@deduire16geo1 * MAILLAGE maianc * MAILLAGE mainouv * MAILLAGE 0res =
+ACIER16MM * MOT OBMOD * MMODEL 0MMM =
+AFFICHE16* RISOM *RIGIDITE FO *CHPOINT S *MAILLAGE AMPDEF *FLOTTANT AMPVEC *FLOTTANT 0=
+AFT116DEP1 * CHPOINT 0DEPnl VITnl =
+AFT2160FNLFRE =
+AJUSTE16tab1 * TABLE 0q p =
+ANIM16GEO * MAILLAGE DEP * CHPOINT AMPL * FLOTTANT 0OBJ =
+ANIME16NFOIS * ENTIER GEO * MAILLAGE DEF * CHPOINT AMPLD * FLOTTANT VEC / CHPOINT 0DEFTOT =
+ANLIMTRE16TABIN * TABLE 0IOK =
+AUTOPILO16DELT * CHPOINT DELA * CHPOINT ZMOD * MMODEL ZMAT * MCHAML TTT *TABLE 0NORM1 =
+BIOVOL16BOBI * MAILLAGE PCAL * MAILLAGE J * CHPOINT MU0 * FLOTTANT 0HGEO =
+BOA16TUYO1 / TABLE 0TUYO2 =
+CALACTIV16TB3 *TABLE TB4 *TABLE LILI *LISTENTI 0CCACT =
+CALCDISP16QELEM * CHPOINT DISPL * CHPOINT DISPT * CHPOINT 0dif_disp =
+CALCP160=
+CALCTRAC16MoDARCY * MMODEL Difftot * MCHAML Cini * CHPOINT nomespec * LISTMOTS nbespece * ENTIER LMLump * LOGIQUE matrtr / MATRIK TABRES * TABLE Tbdartra * TABLE CHCLIM * TABLE 0tcfin MatrTr =
+CALLM160=
+CALMU160=
+CHAMINT16CH1 * CHARGEMENT 0CH2 xstart =
+CHITRNSP16TRANSI * TABLE 0TRANSI =
+CHTGAU16TAB1 *TABLE 0=
+CHTITR16EV1 * EVOLUTION XT / MOT YT / MOT 0EV1 =
+CH_THETA16SUPTAB *TABLE 0TETA TABUTIL =
+CINEMA16MESH0 * MAILLAGE MESH1 * MAILLAGE MESH2 * MAILLAGE VECT1 * POINT 0DEFOT =
+CINEMB16MESH0 * MAILLAGE MESH1 * MAILLAGE MESH2 * MAILLAGE MESH3 * MAILLAGE 0DEFOT =
+CLINC16rxt * TABLE rtf * TABLE TKAS * LOGIQUE NIC *MOT Nj *MOT Nj1 * FLOTTANT Nj2 * FLOTTANT Nj3 * FLOTTANT 0=
+CODENORM16ZTABENT * TABLE 0CODENORM =
+COLLER16VOLUM8 * MAILLAGE SURF4 * MAILLAGE OPT / MOT 0COQMASF =
+COLLER116SURF4 *MAILLAGE POUT2 *MAILLAGE ANG /FLOTTANT 0POUTCOQ =
+COLLER216mod_sh * MMODEL mat_sh * MCHAML mod_so * MMODEL 0KREL2 =
+CONDENS16RXT *TABLE $paroic *MMODEL TP *MOT TF *MOT MRVP *MOT KHcu * FLOTTANT 0QC Fcond Econd Hcond KKC ROVI FHP HT =
+CONTSEG316L1 * MAILLAGE L2 * MAILLAGE 0RIG12 LIG1 LIG2 =
+CONVT16tps * FLOTTANT nn / ENTIER unit / MOT 0out =
+COQ2MAS16MOD1 *MMODEL MAT1 *MCHAML MOTCLE /MOT TAB1 *TABLE 0MESH3D =
+COUPLER160=
+COUR3D16BBBB * MAILLAGE FFAC1 * MAILLAGE FFAC2 * MAILLAGE MMM * MOT J * FLOTTANT NORJ / LOGIQUE 0JJJ =
+COURSPEC16SPECT * LISTREEL DELTT * FLOTTANT 0STASPE =
+CRITLOC16ETAB * TABLE 0STAB =
+CTOD16SUPTAB *TABLE U *CHPOINT 0SUPTAB =
+DARCYSAT16SATUR * TABLE 0=
+DARCYTRA16TRANSI * TABLE 0=
+DDFOUR16GEO * MAILLAGE CHARM * MAILLAGE NHARM * ENTIER SOL * CHPOINT RHARM * FLOTTANT ORIG / POINT LIS * LOGIQUE ITYPE / ENTIER 0AKN ANGVEC =
+DEADFONC160=
+DEADKTAN160=
+DECONV16COUCHE * TABLE FOND_SOL * MAILLAGE SOL / MAILLAGE MOD_SOL DIR * MOT GAMMAO * EVOLUTIO F1 * FLOTTANT F2 * FLOTTANT FC / FLOTTANT TYP_F / MOT P_GAMMA / TABLE 0TABRESU =
+DECONV3D16COUCHE * TABLE PC * POINT FOND_SOL * MAILLAGE MOD_SOL *MMODEL MAT_SOL *MCHAML DIR * MOT GAMMAO * EVOLUTIO F1 * FLOTTANT F2 * FLOTTANT FC / FLOTTANT P_GAMMA / TABLE 0TABRESU =
+DEDANS16P0 *POINT CTR1 *MAILLAGE PREC / FLOTTANT 0=
+DEDUADAP160=
+DEPOU16SGINI *MCHAML TABETAP *TABLE 0TABDEP =
+DESCOUR16TAB * TABLE I * ENTIER BLOCI * MAILLAGE MM * MOT J * FLOTTANT 0=
+DESTRA16TBR * TABLE TBDES0 / TABLE EVOL2 / EVOLUTIO TBDES2 / TABLE 0=
+DIFFANIS16MateDiff * CHPOINT typdi / MOT ANISO / LOGIQUE 0newdiff =
+DREXUS16ETAB * TABLE 0ETAB =
+DUPONT216PRECED * TABLE 0STAB =
+DYNAMIC16ETAB * TABLE 0STAB =
+DYNAMOD216SOLUDY * SOLUTION BASMOD * BASEMODA LISTEM * LISTREEL TEMPCALC * LISTREEL TABL_EVO * TABLE TABL_PAS / TABLE 0RESUEVOL =
+DYNAMOD316BASMOD * BASEMODA SOLUDY * SOLUTION TABL_MAX * TABLE 0RESUMAXI =
+DYNAMODE16_OPERAT_ * MOT TEMPCALC * LISTREEL _BASMOD_ * BASEMODA MOT1 / MOT MOT2 / MOT MOT3 / MOT MOT4 / MOT MOT5 / MOT MOT6 / MOT MOT7 / MOT MOT8 / MOT MOT9 / MOT MO10 / MOT MO11 / MOT AMORT / LISTREEL ENT1 / ENTIER CHP1 / CHPOINT CHP2 / CHPOINT SOLPRE / SOLUTION TAB1 / TABLE TAB2 / TABLE TAB3 / TABLE TAB4 / TABLE TAB5 / TABLE 0RESU =
+EFFMARTI16SIG1 * MCHAML MOD1 * MMODEL MAT1 * MCHAML VECT1 * POINT VECT2 * POINT H1 * FLOTTANT ENRE1 * FLOTTANT ENRI1 * FLOTTANT COT1 * FLOTTANT 0SIG2 =
+ELECNEUT16TB3 *TABLE TBC2 *OBJET TBPAR2 *OBJET LIMODI /LISTENTI 0MSINEUT =
+ENCEINTE16nbit * ENTIER rxt * TABLE KENC / MOT 0=
+ENERMODE16TBASS * TABLE TRESD * TABLE TINIT / TABLE LOG1 / LOGIQUE 0=
+ENRICHIS16SIGNAL * EVOLUTION NIVEAU * ENTIER 0SSIGNAL =
+EXAC160=
+EXIC160=
+EXPLORER160=
+FILC16EV1 * EVOLUTIO F0 * FLOTTANT DF1 * FLOTTANT 0EV3 =
+FLAMBAGE16ETAB11 *TABLE 0STAB11 =
+FORBLOC16BLOC * MAILLAGE SOL1 * CHPOINT COUR * FLOTTANT AXI / LOGIQUE 0RPT RFB =
+FORNOD16LIG1 * MAILLAGE COM1 * MOT FO * FLOTTANT 0FOR1 =
+FOR_CONT16GEO * MAILLAGE SOL1 * CHPOINT COURI * FLOTTANT 0RFORC SMM =
+FPAL160AK =
+FRCTRACE16TAB1 * TABLE TOL1 * FLOTTANT 0TT1 =
+FREPART16FF * POINT LIGNE * MAILLAGE 0CHPF4 =
+FRONABS16TAB_VAL * TABLE TYP_FRON / MOT NHARM / ENTIER 0RIGT =
+FTRAN16EV1 * EVOLUTIO EV2 * EVOLUTIO F0 * FLOTTANT VAL1 / ENTIER 0EV3 =
+F_S2PI16CHARM * MAILLAGE SCIRC * CHPOINT NN * ENTIER OO * POINT 0SCIRC SUPO =
+GAM116x1 *flottant 0(EXP (resu1 ) ) =
+GDFLIM116tab1 *TABLE 0err1 =
+G_CALCUL16SUPTAB * TABLE INFTAB * TABLE 0SUPTAB =
+G_THETA16SUPTAB * TABLE 0SUPTAB =
+G_ULTI2D16TAB1 * TABLE 0VAL1 =
+G_ULTIFR16TAB1 * TABLE 0VAL1 =
+HASOFER16TAB1 *TABLE 0err1 =
+HAUBAN160=
+HRAYO16mcv * MMODEL mor1 * MMODEL mar1 * MCHAML tt1 * CHPOINT mor2 / MMODEL mar2 / MCHAML tt2 * CHPOINT rel12 / MAILLAGE stefan / FLOTTANT 0h =
+HTCTRAN16N_PAS * ENTIER NN_PAS * ENTIER N_ITER * ENTIER T_PAS * FLOTTANT MODL1 * MMODEL TAV1 * TABLE 0TAV1 =
+HTC_CHBW16T0 * CHPOINT H0 * CHPOINT TAV1 * TABLE 0WD DF2 =
+HTC_PER16T0 *CHPOINT HR *CHPOINT TAV1 *TABLE 0AGDG =
+HTC_WTR16TAV1 * TABLE M1 * MOT TA * CHPOINT PA / CHPOINT 0OUT =
+H_B16MU0 * FLOTTANT EVO1 / EVOLUTION F / FLOTTANT 0REVOL =
+IDBHT16M1 * MCHAML MO1 * MMODEL BHTMX * CHPOINT T2 * CHPOINT 0MI IFER =
+IDENTI16NOMMOD *MOT 0=
+IMAGES16TABA * TABLE 0=
+IMPCHI116TB1 * TABLE NOMTB * MOT 0=
+IMPCHI216TB3 * TABLE NOMTB3 * MOT 0=
+INDIBETA16Binf * FLOTTANT Bsup * FLOTTANT Pf * FLOTTANT 0Val =
+INDUCTIO16GEO * MAILLAGE SOL1 * CHPOINT AXI * LOGIQUE 0BTOT =
+INICHI116TB2 *OBJET BASE1 *MOT BASE2 *MOT 0=
+INICHI216TB3 *TABLE TBC2 *OBJET G1 /MAILLAGE 0=
+INICHIMI16TTB1 /OBJET BBD1 /MOT BBD2 /MOT TTB2 /OBJET TTB3 /OBJET G1 /MAILLAGE 0TB2 TB3 TBC2 =
+INIMUR16rxt *TABLE tbt *TABLE 0=
+ININLIN16nop * ENTIER nvar * ENTIER ndat * ENTIER ncof * ENTIER vdim * ENTIER 0A =
+INITEFMH16MoDARCY * MMODEL Porosite * CHPOINT MateDiff * CHPOINT ChPSour * CHPOINT DeltaT * FLOTTANT Cini * CHPOINT TetaDiff * FLOTTANT TetaConv * FLOTTANT TetaLin * FLOTTANT Qface / CHPOINT QELEM / CHPOINT DISPL / CHPOINT DISPT / CHPOINT LMLump * LOGIQUE DECENTR * LOGIQUE CHCLIM * TABLE OPTRESOL / TABLE 0SMTr MatrTr TbDarTra MassEFMH nomespec nbespece nbsource Diffdisp Tcini TABRES TABMODI =
+INITOU16TAB1 *TABLE 0=
+INITVF16MoDARCY * MMODEL Porosite * CHPOINT MateDiff * CHPOINT ChPSour * CHPOINT DeltaT * FLOTTANT Cini * CHPOINT TetaDiff * FLOTTANT TetaConv * FLOTTANT TetaLin * FLOTTANT Qface / CHPOINT QELEM / CHPOINT DISPL / CHPOINT DISPT / CHPOINT CHCLIM * TABLE OPTRESOL / TABLE LCONV * LOGIQUE 0RESI MATOT JACO MPOR2 MCHAMT MCHAMT1 diffdisp difftot nomespec nbespece nbsource TABRES TABMODI NOUVMAT =
+INT_COMP16GEOP * MAILLAGE CCCC * CHPOINT GEOF * MAILLAGE 0CRES =
+IN_MINI16FCAN * MAILLAGE HS * CHPOINT ORIG * POINT B_ANTI * TABLE 0HHHH =
+ISSLEQ16TDON1 * TABLE 0=
+JEU16RIG1 * RIGIDITE 0CHP1 =
+KRESP160=
+KR_PRO16LOI * TABLE SAT * CHPOINT 0K1 =
+KUET160UET =
+KWEIB116x1 *flottant 0k3 =
+LIREFLOT16UMIN * FLOTTANT UMAX * FLOTTANT 0FL =
+MAG_NLIN16ETAB * TABLE 0ETAB =
+MAILVORO16TAB1 * TABLE ENV0 * MAILLAGE NBDIV / ENTIER COEF1 / FLOTTANT MO1 / MOT 0MTRIA1 =
+MDNRIS16P *FLOTTANT 0Y IER =
+MDRECOMB16RXT * TABLE 0=
+MONTAGNE16SMV * CHPOINT SMV2 / CHPOINT GEO * MAILLAGE AMP / FLOTTANT OEIL1 / POINT OEIL2 / LISTREEL 0=
+MRCFRAM116TYP_CAL2 * MOT TAB_IN2 * TABLE TOL_2 * FLOTTANT 0LAM_FIN1 =
+MRCFRAM216TYP_CAL2 * MOT TAB_IN2 * TABLE TOL_2 * FLOTTANT 0LAM_FIN1 =
+MRCFRAM316TYP_CAL2 * MOT TAB_IN2 * TABLE TOL_2 * FLOTTANT 0LAM_FIN1 =
+MRCFRAM416TYP_CAL2 * MOT TAB_IN2 * TABLE TOL_2 * FLOTTANT 0LAM_FIN1 =
+MRCFRAME16TYP_CAL1 * MOT TAB_IN * TABLE TOL_1 * FLOTTANT L_ELE1 / LISTENTI 0TT2 =
+MRCSHELL16TYP_CAL1 * MOT TAB_IN * TABLE TOL_1 * FLOTTANT L_ELE1 / LISTENTI 0TT2 =
+MRCTRACE16TAB1 * TABLE TOL1 * FLOTTANT 0TT1 =
+NOESPCHI16TB1 * TABLE NOM1 / MOT NUM1 / ENTIER 0NOM2 NUNU =
+NORMALIM16M * EVOLUTION DTIME / FLOTTANT 0VALSPE MNORME =
+NORV116v1 *LISTREEL 0nv1 =
+NSCLIM160RESU =
+OUVFISS16TAB1 *TABLE IPAS /ENTIER OPT1 /MOT 0=
+PARASTAT16SUPTAB * TABLE 0MU SIGMA RB1 B2 =
+PASAPAS16PRECED * TABLE 0PRECED =
+PAS_DEFA16PRECED * TABLE 0=
+PAS_EPTH16PRECED *TABLE MODEVAL *MMODEL MATEVAL *MCHAML TCHP /CHPOINT TCHAM /MCHAML 0ETHER2 MSRTHER2 =
+PAS_ETAT16PRECED * TABLE TI * FLOTTANT 0ETAT1 =
+PAS_HELM16PRECED * TABLE 0=
+PAS_INIT16PRECED * TABLE 0=
+PAS_MATE16PRECED * TABLE ETAT * MCHAML 0MMM =
+PAS_REPR16preced * TABLE 0=
+PAS_RESU16TEMP0 * FLOTTANT IAUTO * ENTIER PRECED * TABLE 0ISAUV =
+PAS_VERM16PRECED * TABLE chetat1 * MCHAML 0=
+PECHE16TT *TABLE NOM *MOT VAL /FLOTTANT MOT1 / MOT 0TOTO =
+PFLUAGE16NOMREG *MOT MOBET *MMODEL MABET *MCHAML SIGEPS *MCHAML RAYSECH *MCHAML AGECHAB *FLOTTANT TEMPCOUR *FLOTTANT RHOS *MCHAML TCOULB *FLOTTANT FLOT1 /FLOTTANT FC28 /FLOTTANT 0EPSFLU =
+PHASAGE16TABPHAS 0TABPHAS =
+PMPB16TSIG *chpoint LIG *maillage grapl *logique nnc *entier nne *entier 0TABV =
+POINTSPH16LONG * FLOTTANT TETA * FLOTTANT PHI * FLOTTANT 0PT =
+POSTDDI16tab *TABLE tabmat *TABLE geo *MAILLAGE periode *FLOTTANT nperi *ENTIER idebu *ENTIER 0nf nc nr dfin =
+POSTDDI116var1 *MCHAML alpha *FLOTTANT mod0 *MMODEL 0chi =
+POSTOU16TAB1 *TABLE DIST /FLOTTANT 0=
+POSTVIBR16TBAS1 * TABLE LMOC1 / LISTMOTS TOPT1 / TABLE 0=
+POT_SCAL16TABGEO * TABLE SOLIN /MOT 0=
+POT_VECT16MATAB * TABLE SOLIN / MOT 0=
+PREPAENC16rxt * TABLE TBT * TABLE geo * TABLE TIC * TABLE 0=
+PROBABRS16MuR * FLOTTANT SigR * FLOTTANT rR * FLOTTANT bR * FLOTTANT MuS * FLOTTANT SigS * FLOTTANT rS * FLOTTANT bS * FLOTTANT 0Pf =
+PROBDENS16MU * FLOTTANT SIGMA * FLOTTANT RB1 * FLOTTANT B2 * FLOTTANT 0PDF CDF =
+PROCHEXT16TPS * FLOTTANT rxt * TABLE KASX * MOT 0=
+PRODT160=
+PROJGRIL16nuag1 * NUAGE 0mail1 chp2 =
+PROPAG16ETAB * TABLE 0EVO6 =
+PSATT160=
+QUADRATU16LOI * MOT MU * FLOTTANT SIGMA * FLOTTANT N * ENTIER 0RESTAB =
+RAMBERG16TAB1 * TABLE 0TAB1 =
+RDIV160=
+RECENTRE16CHP1 * CHPOINT MMO * MMODEL NIV * MOT 0=
+RECOMPOM16MRESI * EVOLUTION MDECO * EVOLUTION DTIME * FLOTTANT CRESI / FLOTTANT CDECO / LISTREEL OPTIO / TABLE 0M ACC =
+RECOMPOS16RESI * EVOLUTION DECO * EVOLUTION OPTIO / TABLE 0M ACC =
+REPIX160=
+RESEAU16TAB * TABLE NIND * ENTIER PARAM * FLOTTANT 0EVN =
+RESO_ASY16RIGI_ASY * RIGIDITE CHP_FORC * CHPOINT 0CHP_DEPL =
+RESPOWNS16RSNS * EVOLUTION M * EVOLUTION FREQ * LISTREEL OPTION / TABLE 0PSNS =
+RESPOWSP16RSPE * EVOLUTION TE * FLOTTANT AMOR * LISTREEL OPTION / TABLE 0PSPE =
+RETRAIT16NOMREG *MOT MOBET *MMODEL RAYSECH *MCHAML TCOULB *FLOTTANT TEMPCOUR *FLOTTANT FLOT1 *FLOTTANT RHOS *MCHAML FC28 /FLOTTANT 0EPSRET =
+ROSENT16TAB1 *TABLE 0=
+ROTA_IMP16monmail * MAILLAGE angle * FLOTTANT poin1 * POINT poin2 * POINT 0rrota lrota =
+SATUTILS160=
+SGE160=
+SHFDT16TABDON 0FDTSH =
+SIF16SUPTAB *TABLE MAT *MCHAML U *CHPOINT 0SUPTAB =
+SIGNCORR16ZZTB * TABLE 0ZSIGN =
+SIGNDERI16EVSIG1 * EVOLUTIO 0EVSIG2 =
+SIGNENVE16ZZTA * TABLE 0ZENV =
+SIGNSYNT16MOT1 * MOT ZTAB * TABLE 0ZTEVSIG =
+SOLVEFMH16MoDARCY * MMODEL ChPSour * CHPOINT MassEFMH * RIGIDITE MatTR / RIGIDITE matTM / MATRIK SMTR * CHPOINT Tcini * CHPOINT cini * CHPOINT QFACE / CHPOINT nomespec * LISTMOTS nbespece * ENTIER nbsource * ENTIER TABRES * TABLE tbdartra * TABLE CHCLIM * TABLE 0mattr TABSORT cfin tcfin cflu cfluco =
+SOLVVF16MoDARCY * MMODEL ChPSour * CHPOINT matk / MATRIK SMTR * CHPOINT cini * CHPOINT Mctot * MCHAML Mdiff * MCHAML Difftot * CHPOINT RESID * CHPOINT TetaDiff * FLOTTANT QFACE / CHPOINT nomespec * LISTMOTS nbespece * ENTIER nbsource * ENTIER TABRES * TABLE CHCLIM * TABLE NOUVMAT * LOGIQUE LCONV * LOGIQUE CHTR * LOGIQUE 0matk TABSORT cfin cflu cfluco RESI =
+TENSION16TABETAP 0TABETAP =
+THERMIC160ETAB =
+TOPOFILT16tab0 * TABLE 0=
+TOPOMATE16mod0 * MMODEL mat0 * MCHAML dens0 * MCHAML 0mat1 =
+TRAC3D16ZMAIL *MAILLAGE ZCHPU *CHPOINT ZAM *FLOTTANT ZANGL *FLOTTANT ZM *ENTIER ZN *ENTIER ZXVISU *FLOTTANT ZYVISU *FLOTTANT ZZVISU *FLOTTANT ZINTER *LOGIQUE 0=
+TRAC3D_216ZZMAIL / MAILLAGE ZZCHPU1 / CHPOINT ZZCHPU2 / MCHAML MODL0 / MMODEL ZANGL * FLOTTANT ZM * ENTIER ZN * ENTIER 0TAB1 =
+TRACHIS16TAB2 * TABLE NOMT * MOT LIGNE * MAILLAGE LIINDT / LISTENTI LIT / LISTREEL LICOMP / LISTMOTS LICOMP2 / LISTMOTS TNOMCOMP / TABLE 0TBR =
+TRACHIT16TAB2 * TABLE NOMT * MOT LIGNE * MAILLAGE LIINDT / LISTENTI LIT / LISTREEL LICOMP / LISTMOTS TNOMCOMP / TABLE TNOMPT / TABLE 0TBR =
+TRACTUFI16ETAB * TABLE 0MP CM KF =
+TRADUIRE16OBJ_SOL /SOLUTION OBJ_TAB /TABLE 0TTRAD =
+TRANSGEN16TRANSI * TABLE 0=
+TRANSIT216ETAB * TABLE 0ETAB =
+TRANSLIN16PRECED * TABLE 0STAB =
+TRANSNON16PRECED * TABLE 0STAB =
+TRC16MODTHE * MMODEL MATPHAS * MCHAML TPHASE * TABLE TINI *FLOTTANT TFIN *FLOTTANT LISTREF *LISTREEL 0=
+TRTRAJEC16UUUU * TABLE 0CROB =
+T_IPOL16t *FLOTTANT rxt *TABLE 0=
+T_PITETA16TABMOD * TABLE MATERI * MCHAML SUPTAB * TABLE 0SUPTAB =
+UNPAS16PRECED * TABLE 0STAB12 =
+UPDAEFMH16MoDARCY * MMODEL Porosite * CHPOINT MateDiff * CHPOINT Diffdisp * CHPOINT ChPSour * CHPOINT Cini * CHPOINT Tcini * CHPOINT Deltat * FLOTTANT Qface / CHPOINT nomespec * LISTMOTS nbespece * ENTIER nbsource * ENTIER LMLump * LOGIQUE DECENTR * LOGIQUE massEFMH * RIGIDITE mattr / MATRIK mattm / RIGIDITE Tbdartra * TABLE TABMODI * TABLE CHCLIM * TABLE 0SMTr MatrTr TbDarTra MassEFMH =
+UPDAVF16MoDARCY * MMODEL Porosite * CHPOINT Matediff * CHPOINT Diffdisp * CHPOINT ChPSour * CHPOINT Deltat * FLOTTANT Cini * CHPOINT TetaDiff * FLOTTANT TetaConv * FLOTTANT Qface / CHPOINT nomespec * LISTMOTS nbespece * ENTIER nbsource * ENTIER mattr * MATRIK JACO * MATRIK MPOR2 * MATRIK MCHAMT * MCHAML MCHAMT1 * MCHAML TABMODI * TABLE CHCLIM * TABLE LCONV * LOGIQUE 0RESI Matot Difftot MCHAMT MCHAMT1 NOUVMAT =
+VALSPE16NNORO * LISTREEL NNORR * FLOTTANT DELTT * FLOTTANT 0SPECT =
+VAPDIF16PM *FLOTTANT TM *CHPOINT YV *CHPOINT YH2 *CHPOINT YHE *CHPOINT YO2 *CHPOINT YN2 *CHPOINT YCO2 *CHPOINT YCO *CHPOINT 0=
+VARIHC16TAB2 * TABLE 0MATR1 =
+VARIHCSU16TAB2 * TABLE 0MATR1 =
+VERTYTAB160=
+VITETFOR16MTA * TABLE ETAB12 * TABLE FCORU * CHPOINT 0VADD FADD =
+VITEUNIL16ROP * RIGIDITE M * RIGIDITE V * CHPOINT DX * CHPOINT DEPINI * CHPOINT H * FLOTTANT RESI * CHPOINT PRECED * TABLE 0VAUX =
+VNIMP160=
+VTIMP160=
+WEIBULL16ZSIG *MCHAML ZOBMO *MMODEL ZV0 *FLOTTANT ZSIGU *FLOTTANT ZSIG0 *FLOTTANT ZXN *FLOTTANT 0ZXP ZSIGF =
+ZIGZAG160GEO1 =
+ZONFIS16TAB1 *TABLE PHA /ENTIER PBA /ENTIER NHA /ENTIER NBA /ENTIER HAU /FLOTTANT BAS /FLOTTANT GAU /FLOTTANT DRO /FLOTTANT ALPHA /FLOTTANT 0=
+asparam16rxt *TABLE 0=
+broche16KAS * MOT nab * ENTIER rxt * TABLE 0=
+bruche16KAS * MOT nab * ENTIER rxt * TABLE 0=
+charther16PRECED * TABLE tt * FLOTTANT 0=
+cormasse16GAZ * MOT Rmzn * FLOTTANT Mdrvap * MOT 0=
+fdens16tpar *table xi *flottant 0xdens =
+fiabili16tab *table 0tab =
+finvrepa16TPARI *table xi *flottant 0INVREP =
+limemeca16mod1 * MMODEL tab1 * TABLE tab2 * TABLE mch1 * MCHAML chp1 * CHPOINT chp2 / CHPOINT coeff / FLOTTANT 0lok colim1 chdlim1 chrlim1 =
+mailstru16co * MAILLAGE dd * FLOTTANT 0res =
+nataf16tab1 *table 0=
+repart16TPARI *table xi *flottant 0REP =
+retsat160=
+rvsat160rvs rvp =
+rvst2160rvs rvp =
+tracmeca16mod1 * MMODEL tab1 * TABLE tab2 * TABLE coeff / FLOTTANT 0tab3 =
\ No newline at end of file
diff --git a/scintilla/Makefile.am b/scintilla/Makefile.am
index a5b7e962..62e2619e 100644
--- a/scintilla/Makefile.am
+++ b/scintilla/Makefile.am
@@ -47,7 +47,8 @@ lexers/LexTCL.cxx \
 lexers/LexTxt2tags.cxx \
 lexers/LexVHDL.cxx \
 lexers/LexVerilog.cxx \
-lexers/LexYAML.cxx
+lexers/LexYAML.cxx \
+lexers/LexGIBIANE.cxx
 
 SRCS= \
 gtk/Converter.h \
diff --git a/scintilla/include/SciLexer.h b/scintilla/include/SciLexer.h
index ae20985c..5dbe4e65 100644
--- a/scintilla/include/SciLexer.h
+++ b/scintilla/include/SciLexer.h
@@ -140,6 +140,7 @@
 #define SCLEX_SAS 125
 #define SCLEX_NIM 126
 #define SCLEX_CIL 127
+#define SCLEX_GIBIANE 128
 #define SCLEX_LPEG 999
 #define SCLEX_AUTOMATIC 1000
 #define SCE_P_DEFAULT 0
@@ -1886,6 +1887,19 @@
 #define SCE_CIL_OPERATOR 8
 #define SCE_CIL_IDENTIFIER 9
 #define SCE_CIL_STRINGEOL 10
+#define SCE_GIBIANE_DEFAULT 0
+#define SCE_GIBIANE_COMMENT 1
+#define SCE_GIBIANE_STRING 2
+#define SCE_GIBIANE_NUMBER 3
+#define SCE_GIBIANE_TABLE 4
+#define SCE_GIBIANE_WORD 5
+#define SCE_GIBIANE_WORD2 6
+#define SCE_GIBIANE_WORD3 7
+#define SCE_GIBIANE_WORD4 8
+#define SCE_GIBIANE_WORD5 9
+#define SCE_GIBIANE_WORD6 10
+#define SCE_GIBIANE_WORD7 11
+#define SCE_GIBIANE_WORD8 12
 /* --Autogenerated -- end of section automatically generated from Scintilla.iface */
 
 #endif
diff --git a/scintilla/include/Scintilla.iface b/scintilla/include/Scintilla.iface
index c009371c..3b5bafaa 100644
--- a/scintilla/include/Scintilla.iface
+++ b/scintilla/include/Scintilla.iface
@@ -2976,6 +2976,7 @@ val SCLEX_STATA=124
 val SCLEX_SAS=125
 val SCLEX_NIM=126
 val SCLEX_CIL=127
+val SCLEX_GIBIANE=128
 val SCLEX_LPEG=999
 
 # When a lexer specifies its language as SCLEX_AUTOMATIC it receives a
@@ -4930,7 +4931,7 @@ val SCE_SAS_MACRO_KEYWORD=12
 val SCE_SAS_BLOCK_KEYWORD=13
 val SCE_SAS_MACRO_FUNCTION=14
 val SCE_SAS_STATEMENT=15
-# Lexical states for SCLEX_NIM 
+# Lexical states for SCLEX_NIM
 lex Nim=SCLEX_NIM SCE_NIM_
 val SCE_NIM_DEFAULT=0
 val SCE_NIM_COMMENT=1
@@ -4962,6 +4963,21 @@ val SCE_CIL_LABEL=7
 val SCE_CIL_OPERATOR=8
 val SCE_CIL_IDENTIFIER=9
 val SCE_CIL_STRINGEOL=10
+# Lexical states for SCLEX_GIBIANE
+lex GIBIANE=SCLEX_GIBIANE SCE_GIBIANE_
+val SCE_GIBIANE_DEFAULT=0
+val SCE_GIBIANE_COMMENT=1
+val SCE_GIBIANE_STRING=2
+val SCE_GIBIANE_NUMBER=3
+val SCE_GIBIANE_TABLE=4
+val SCE_GIBIANE_WORD=5
+val SCE_GIBIANE_WORD2=6
+val SCE_GIBIANE_WORD3=7
+val SCE_GIBIANE_WORD4=8
+val SCE_GIBIANE_WORD5=9
+val SCE_GIBIANE_WORD6=10
+val SCE_GIBIANE_WORD7=11
+val SCE_GIBIANE_WORD8=12
 
 # Events
 
diff --git a/scintilla/lexers/LexGIBIANE.cxx b/scintilla/lexers/LexGIBIANE.cxx
new file mode 100644
index 00000000..18a9a1dd
--- /dev/null
+++ b/scintilla/lexers/LexGIBIANE.cxx
@@ -0,0 +1,376 @@
+/* Scintilla source code edit control
+ * @file LexGIBIANE.cxx
+ * Lexer for GIBIANE.
+ *
+ * Copyright 2019 Thibault Lindecker (Communication & Systemes) - thibault.lindecker@c-s.fr
+ * The License.txt file describes the conditions under which this software may be distributed. */
+
+#include <stdlib.h>
+#include <string.h>
+#include <stdio.h>
+#include <stdarg.h>
+#include <assert.h>
+#include <ctype.h>
+
+#include "ILexer.h"
+#include "Scintilla.h"
+#include "SciLexer.h"
+
+#include "WordList.h"
+#include "LexAccessor.h"
+#include "Accessor.h"
+#include "StyleContext.h"
+#include "CharacterSet.h"
+#include "LexerModule.h"
+
+using namespace Scintilla;
+
+class Is_ {
+    private:
+        static bool ret;
+        bool parenthesis(char c);
+        bool equal(char c);
+        bool digit(char c);
+    public:
+        Is_();
+        bool lineend(char c);
+        bool blanck(char c);
+        bool ANumber(char c, char cPrev, char cNext);
+        bool SPECIAL(char c);
+        bool quote(char c);
+        bool semicolon(char c);
+};
+Is_::Is_(void){}
+bool Is_::ret = false;
+bool Is_::blanck(char c) {
+    return ((c == ' ') || (c == 0x09) || (c == 0x0b));
+}
+bool Is_::lineend(char c) {
+    return ((c == '\n') || (c == '\r'));
+}
+bool Is_::semicolon(char c) {
+    return (c == ';');
+}
+bool Is_::parenthesis(char c) {
+    return c == '(' || c == ')';
+}
+bool Is_::equal(char c) {
+    return c == '=';
+}
+bool Is_::digit(char c) {
+    return IsADigit(c);
+}
+bool Is_::quote(char c) {
+    return (c == '\'');
+}
+bool Is_::SPECIAL(char c){
+    return (blanck(c) || lineend(c) || semicolon(c) || parenthesis(c) || equal(c));
+}
+bool Is_::ANumber(char c, char cPrev, char cNext) {
+    if (digit(c) || (c == '.' && digit(cNext))) {
+        if(cPrev == '.' || (digit(cPrev) && ret) || SPECIAL(cPrev)){
+            if(cNext == '.' || digit(cNext) || SPECIAL(cNext)){
+                ret = true;
+                return ret;
+            }
+        }
+    }
+    ret = false;
+    return ret;
+}
+
+/* Set colorization for GIBIANE language. See the file 'data/filedefs/filetypes.gibiane' */
+static void ColouriseGIBIANEDoc(Sci_PositionU startPos, Sci_Position length, int initStyle,
+           WordList *keywordlists[], Accessor &styler) {
+
+  Is_ Is;
+  WordList &keywords  = *keywordlists[0];
+  WordList &keywords2 = *keywordlists[1];
+  WordList &keywords3 = *keywordlists[2];
+  WordList &keywords4 = *keywordlists[3];
+  WordList &keywords5 = *keywordlists[4];
+  WordList &keywords6 = *keywordlists[5];
+  WordList &keywords7 = *keywordlists[6];
+  WordList &keywords8 = *keywordlists[7];
+  WordList &keywords9 = *keywordlists[8];
+  styler.StartAt(startPos);
+
+  Sci_Position endPos = startPos + length;
+  startPos = styler.LineStart(styler.GetLine(startPos));
+  initStyle = styler.StyleAt(startPos - 1);
+  length = endPos - startPos;
+
+  StyleContext sc(startPos, length, initStyle, styler);
+
+  Sci_Position posLineStart = 0;
+  int numNonBlank = 0, prevState = 0;
+
+  for (; sc.More(); sc.Forward()) {
+
+        char s[100];
+        sc.GetCurrentLowered(s, sizeof(s));
+        char ch = s[0];
+        char *s2 = &s[1];
+
+    if (sc.state == SCE_GIBIANE_COMMENT) {
+      if (sc.atLineEnd) {
+        sc.SetState(SCE_GIBIANE_DEFAULT);
+        sc.ChangeState(SCE_GIBIANE_DEFAULT);
+      }
+    } else if (sc.state == SCE_GIBIANE_STRING) {
+      if (sc.ch == '\'') {
+       /* In GIBIANE, we can protect operator with apostrophe.
+        * So we have to check for operator now. */
+        if ( keywords.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        }
+        else if ( keywords2.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD2);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords3.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD3);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords4.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD4);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords5.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD5);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords6.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD6);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords7.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD7);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords8.InList(s2) ) {
+            sc.Forward();
+            sc.ChangeState(SCE_GIBIANE_WORD8);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        }
+        else{
+            sc.ForwardSetState(SCE_GIBIANE_DEFAULT);
+        }
+      }
+    }
+    else if (sc.state == SCE_GIBIANE_NUMBER) {
+      sc.SetState(SCE_GIBIANE_DEFAULT);
+    }
+    else if (Is.SPECIAL(ch)) {
+      sc.SetState(SCE_GIBIANE_DEFAULT);
+    }
+
+    if (sc.state == SCE_GIBIANE_DEFAULT) {
+
+      /* In GIBIANE, comments line start with '*'. */
+      if (sc.ch == '*' && (Is.lineend(sc.chPrev) || sc.currentPos == startPos)) {
+        sc.SetState(SCE_GIBIANE_COMMENT);
+      } else if (sc.ch == '\'') {
+        sc.SetState(SCE_GIBIANE_STRING);
+      }
+      else if (Is.ANumber(sc.ch, sc.chPrev, sc.chNext)) {
+        sc.SetState(SCE_GIBIANE_NUMBER);
+      }
+       /* We check for operator */
+      else if (Is.SPECIAL(sc.ch)) {
+        if ( keywords.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        }
+        else if ( keywords2.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD2);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords3.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD3);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords4.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD4);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords5.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD5);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords6.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD6);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords7.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD7);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else if ( keywords8.InList(s) ) {
+            sc.ChangeState(SCE_GIBIANE_WORD8);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        } else {
+            sc.ChangeState(SCE_GIBIANE_DEFAULT);
+            sc.SetState(SCE_GIBIANE_DEFAULT);
+        }
+      }
+      else if (sc.ch == '.'){
+          sc.ChangeState(SCE_GIBIANE_TABLE);
+          sc.SetState(SCE_GIBIANE_DEFAULT);
+      }
+    }
+
+  }
+  sc.Complete();
+}
+
+/* Set level.
+ * 1) we manage the 'if - else' block :
+ *  SI;
+ *    do something
+ *  SINON;
+ *    do something
+ *  FINSI;
+ * 2) we manage the 'for loop' block :
+ *  REPETER I 10;
+ *    do something
+ *  FIN I;
+ * 3) we manage the 'DEBM' block :
+ *  DEBMETH A;
+ *    do something
+ *  FINMETH B;
+ * 4) we manage the 'DEBP' block :
+ *  DEBPROC myprocedure toto*'TABL';
+ *    do something
+ *  FINPROC titi*'MOTS' tata*'ENTIER'
+ * */
+static void FoldGIBIANEDoc(Sci_PositionU startPos, Sci_Position length, int initStyle,
+            WordList *[], Accessor &styler) {
+  Is_ Is;
+  Sci_PositionU endPos = startPos + length;
+  int levelDeltaNext = 0;
+  Sci_Position lineCurrent = styler.GetLine(startPos);
+  static bool atEOL = false;
+  static bool atEOLPast = atEOL;
+  bool isPrevLine;
+
+  if (lineCurrent > 0) {
+    lineCurrent--;
+    startPos = styler.LineStart(lineCurrent);
+    isPrevLine = true;
+  } else {
+    isPrevLine = false;
+  }
+  char chNext = styler[startPos];
+  int styleNext = styler.StyleAt(startPos);
+  int style = initStyle;
+  Sci_PositionU lastStart = 0;
+  int visibleChars = 0;
+  int levelCurrent = styler.LevelAt(lineCurrent) & SC_FOLDLEVELNUMBERMASK;
+  static bool line_comment = false;
+
+  for (Sci_PositionU i = startPos; i < endPos; i++) {
+
+    char ch = chNext;
+    chNext = styler.SafeGetCharAt(i + 1);
+    int stylePrev = style;
+    style = styleNext;
+    styleNext = styler.StyleAt(i + 1);
+
+    if(stylePrev == SCE_GIBIANE_DEFAULT){
+      lastStart = i;
+    }
+    if( Is.blanck(ch) || Is.lineend(ch) || Is.quote(ch) ){
+      lastStart = i+1;
+    }
+
+    if( (ch == '*' && (atEOLPast || atEOL)) || line_comment ){
+        line_comment = true;
+        lastStart = i+1;
+        visibleChars = 0;
+    }
+
+    if( (Is.SPECIAL(chNext) || Is.quote(chNext)) && !line_comment && style != SCE_GIBIANE_STRING ){
+
+      char s[32];
+      Sci_PositionU k;
+      for(k=0; (k<31 ) && (k<i-lastStart+1 ); k++) {
+          s[k] = static_cast<char>(tolower(styler[lastStart+k]));
+      }
+      s[k] = '\0';
+      int keyword_min_size = ((int)k < 4) ? 4 : (int)k;
+
+      if (strcmp(s, "si") == 0 || strncmp(s, "repeter", keyword_min_size) == 0 ||
+          strncmp(s, "debproc", keyword_min_size) == 0 || strncmp(s, "debmeth", keyword_min_size) == 0){
+
+        levelDeltaNext++;
+
+      }
+      else if(strncmp(s, "finsi", keyword_min_size) == 0 || strcmp(s, "fin") == 0 ||
+              strncmp(s, "finproc", keyword_min_size) == 0 || strncmp(s, "finmeth", keyword_min_size) == 0){
+
+        if(strcmp(s, "fin") == 0){ /* On doit alors verifier que c'est pas un "fin;" mais bien un "fin boucle;"*/
+          char c = 0;
+          Sci_PositionU p;
+          for(p=lastStart+k; p<endPos; p++){
+            c = static_cast<char>(tolower(styler[p]));
+            if(! Is.blanck(c) && ! Is.semicolon(c) && ! Is.quote(c)){ //On n'est pas sur un "fin ;" mais bien un "fin boucle;"
+              levelDeltaNext--;
+              break;
+            }
+            else if(Is.semicolon(c)){
+              break;
+            }
+          }
+        }
+        else{
+          levelDeltaNext--;
+        }
+
+      }
+      else if(strncmp(s, "sinon", keyword_min_size) == 0){
+
+        if(!isPrevLine){
+            levelCurrent--;
+        }
+        levelDeltaNext++;
+
+      }
+
+    }
+
+    atEOLPast = atEOL;
+    atEOL = (ch == '\r' && chNext != '\n') || (ch == '\n');
+    if (atEOL) {
+      int lev = levelCurrent;
+      bool foldCompact = styler.GetPropertyInt("fold.compact", 1) != 0;
+
+      if (visibleChars == 0 && foldCompact)
+          lev |= SC_FOLDLEVELWHITEFLAG;
+      if ((levelDeltaNext > 0) && (visibleChars > 0))
+          lev |= SC_FOLDLEVELHEADERFLAG;
+      if (lev != styler.LevelAt(lineCurrent))
+          styler.SetLevel(lineCurrent, lev);
+
+      lineCurrent++;
+      levelCurrent += levelDeltaNext;
+      levelDeltaNext = 0;
+      visibleChars = 0;
+      isPrevLine = false;
+      line_comment = false;
+    }
+
+    if (!isspacechar(ch)) visibleChars++;
+  }
+
+}
+
+static const char *const GIBIANEWordLists[] = {
+  "conditional",
+  "test1",
+  "loop",
+  "task",
+  "element",
+  "function1",
+  "function2",
+  "operator",
+  0
+};
+
+LexerModule lmGIBIANE(SCLEX_GIBIANE, ColouriseGIBIANEDoc, "GIBIANE", FoldGIBIANEDoc, GIBIANEWordLists);
diff --git a/scintilla/src/Catalogue.cxx b/scintilla/src/Catalogue.cxx
index 01f20c64..2ffc5dd2 100644
--- a/scintilla/src/Catalogue.cxx
+++ b/scintilla/src/Catalogue.cxx
@@ -118,6 +118,7 @@ int Scintilla_LinkLexers() {
 	LINK_LEXER(lmVHDL);
 	LINK_LEXER(lmXML);
 	LINK_LEXER(lmYAML);
+	LINK_LEXER(lmGIBIANE);
 
 //--Autogenerated -- end of automatically generated section
 
diff --git a/scripts/create_dgibi_tags.sh b/scripts/create_dgibi_tags.sh
new file mode 100755
index 00000000..efc7ec72
--- /dev/null
+++ b/scripts/create_dgibi_tags.sh
@@ -0,0 +1,32 @@
+#!/bin/sh
+#
+# License: GPL v2 or later
+#
+# Copyright 2019 Thibault Lindecker (Communication & Systemes) - thibault.lindecker@c-s.fr
+#
+# Create a dgibi tags file for Geany from '.procedur' files
+#
+
+CASTEM_VERSION=19
+CASTEM_EXISTE=`which castem${CASTEM_VERSION}`
+if [ $? -ne 0 ] ; then
+  echo "You need to have Cast3M 20${CASTEM_VERSION} developper edition installed to run this script"
+  echo "See http://www-cast3m.cea.fr/index.php"
+  exit 1
+fi
+CASTEM_PROCEDURES="$(dirname ${CASTEM_EXISTE})/../procedur/*"
+if [ $? -ne 0 ] ; then
+  echo "You need to have Cast3M 20${CASTEM_VERSION} developper edition installed to run this script"
+  echo "See http://www-cast3m.cea.fr/index.php"
+  exit 1
+fi
+
+tmpfile="tmp.dgibi.tags"
+tagfile="data/tags/std.dgibi.tags"
+
+# generation du fichier de tags
+geany -g ${tmpfile} ${CASTEM_PROCEDURES}
+
+# On ne garde que les tags des procedures (pas ceux des variables)
+grep -a "=" ${tmpfile} > ${tagfile}
+rm ${tmpfile}
diff --git a/src/editor.c b/src/editor.c
index 620248c4..5990f679 100644
--- a/src/editor.c
+++ b/src/editor.c
@@ -832,6 +832,15 @@ static void on_char_added(GeanyEditor *editor, SCNotification *nt)
 			editor_show_calltip(editor, --pos);
 			break;
 		}
+		case ' ':
+		{
+			if(editor->document->file_type->id == GEANY_FILETYPES_GIBIANE){
+				auto_close_chars(sci, pos, nt->ch);
+				/* show calltips */
+				editor_show_calltip(editor, --pos);
+			}
+			break;
+		}
 		case ')':
 		{	/* hide calltips */
 			if (SSM(sci, SCI_CALLTIPACTIVE, 0, 0))
@@ -845,6 +854,21 @@ static void on_char_added(GeanyEditor *editor, SCNotification *nt)
 			calltip.set = FALSE;
 			break;
 		}
+		case ';':
+		{ /* hide calltips */
+			if(editor->document->file_type->id == GEANY_FILETYPES_GIBIANE){
+				if (SSM(sci, SCI_CALLTIPACTIVE, 0, 0))
+				{
+					SSM(sci, SCI_CALLTIPCANCEL, 0, 0);
+				}
+				g_free(calltip.text);
+				calltip.text = NULL;
+				calltip.pos = 0;
+				calltip.sci = NULL;
+				calltip.set = FALSE;
+			}
+			break;
+		}
 		case '{':
 		case '[':
 		case '"':
diff --git a/src/filetypes.c b/src/filetypes.c
index 78af8850..f87755d5 100644
--- a/src/filetypes.c
+++ b/src/filetypes.c
@@ -185,6 +185,7 @@ static void init_builtin_filetypes(void)
 	FT_INIT( COFFEESCRIPT, NONE,       "CoffeeScript",     NULL,                      SOURCE_FILE, SCRIPT   );
 	FT_INIT( GO,         GO,           "Go",               NULL,                      SOURCE_FILE, COMPILED );
 	FT_INIT( ZEPHIR,     ZEPHIR,       "Zephir",           NULL,                      SOURCE_FILE, COMPILED );
+	FT_INIT( GIBIANE,    GIBIANE,      "GIBIANE",          NULL,                      SOURCE_FILE, SCRIPT   );
 }
 
 
diff --git a/src/filetypes.h b/src/filetypes.h
index debd618d..c8783dcd 100644
--- a/src/filetypes.h
+++ b/src/filetypes.h
@@ -105,6 +105,7 @@ typedef enum
 	GEANY_FILETYPES_COFFEESCRIPT,
 	GEANY_FILETYPES_GO,
 	GEANY_FILETYPES_ZEPHIR,
+	GEANY_FILETYPES_GIBIANE,
 	/* ^ append items here */
 	GEANY_MAX_BUILT_IN_FILETYPES	/* Don't use this, use filetypes_array->len instead */
 }
diff --git a/src/highlighting.c b/src/highlighting.c
index 65d15164..0686abf6 100644
--- a/src/highlighting.c
+++ b/src/highlighting.c
@@ -1051,6 +1051,7 @@ void highlighting_init_styles(guint filetype_idx, GKeyFile *config, GKeyFile *co
 		init_styleset_case(XML);
 		init_styleset_case(YAML);
 		init_styleset_case(ZEPHIR);
+		init_styleset_case(GIBIANE);
 		default:
 			if (ft->lexer_filetype)
 				geany_debug("Filetype %s has a recursive lexer_filetype %s set!",
@@ -1139,6 +1140,7 @@ void highlighting_set_styles(ScintillaObject *sci, GeanyFiletype *ft)
 		styleset_case(XML);
 		styleset_case(YAML);
 		styleset_case(ZEPHIR);
+		styleset_case(GIBIANE);
 		case GEANY_FILETYPES_NONE:
 		default:
 			styleset_default(sci, ft->id);
@@ -1841,6 +1843,10 @@ gboolean highlighting_is_comment_style(gint lexer, gint style)
 		case SCLEX_MARKDOWN:
 			/* there is no comment type in those lexers, listing here just for completeness */
 			return FALSE;
+
+		case SCLEX_GIBIANE:
+			return (style == SCE_GIBIANE_COMMENT);
+
 	}
 	return FALSE;
 }
diff --git a/src/highlightingmappings.h b/src/highlightingmappings.h
index 726ab2e2..4bf74658 100644
--- a/src/highlightingmappings.h
+++ b/src/highlightingmappings.h
@@ -1625,6 +1625,38 @@ static const HLKeyword highlighting_keywords_YAML[] =
 #define highlighting_keywords_ZEPHIR	highlighting_keywords_PHP
 #define highlighting_properties_ZEPHIR	highlighting_properties_PHP
 
+/* GIBIANE */
+#define highlighting_lexer_GIBIANE		SCLEX_GIBIANE
+static const HLStyle highlighting_styles_GIBIANE[] =
+{
+	{ SCE_GIBIANE_DEFAULT,			"default",			FALSE },
+	{ SCE_GIBIANE_COMMENT,			"comment",			FALSE },
+	{ SCE_GIBIANE_STRING,			"string",			FALSE },
+	{ SCE_GIBIANE_NUMBER,			"number",			FALSE },
+	{ SCE_GIBIANE_TABLE,			"table",			FALSE },
+	{ SCE_GIBIANE_WORD,				"word",				FALSE },
+	{ SCE_GIBIANE_WORD2,			"word2",			FALSE },
+	{ SCE_GIBIANE_WORD3,			"word3",			FALSE },
+	{ SCE_GIBIANE_WORD4,			"word4",			FALSE },
+	{ SCE_GIBIANE_WORD5,			"word5",			FALSE },
+	{ SCE_GIBIANE_WORD6,			"word6",			FALSE },
+	{ SCE_GIBIANE_WORD7,			"word7",			FALSE },
+	{ SCE_GIBIANE_WORD8,			"word8",			FALSE }
+};
+
+static const HLKeyword highlighting_keywords_GIBIANE[] =
+{
+	{ 0, "conditional",	FALSE },
+	{ 1, "test1",		FALSE },
+	{ 2, "loop",		FALSE },
+	{ 3, "task",	    FALSE },
+	{ 4, "element",		FALSE },
+	{ 5, "function1",	FALSE },
+	{ 6, "function2",	FALSE },
+	{ 7, "operator",	FALSE }
+};
+#define highlighting_properties_GIBIANE	    EMPTY_PROPERTIES
+
 G_END_DECLS
 
 #endif /* GEANY_HIGHLIGHTING_MAPPINGS_H */
diff --git a/src/symbols.c b/src/symbols.c
index c4d017f1..fb1d8af1 100644
--- a/src/symbols.c
+++ b/src/symbols.c
@@ -1667,7 +1667,7 @@ int symbols_generate_global_tags(int argc, char **argv, gboolean want_preprocess
 		geany_debug("Generating %s tags file.", ft->name);
 		tm_get_workspace();
 		status = tm_workspace_create_global_tags(command, (const char **) (argv + 2),
-												 argc - 2, tags_file, ft->lang);
+												 argc - 2, tags_file, ft->lang, ft->pattern[0]);
 		g_free(command);
 		symbols_finalize(); /* free c_tags_ignore data */
 		if (! status)
diff --git a/src/tagmanager/tm_parser.c b/src/tagmanager/tm_parser.c
index c3fda335..802d5626 100644
--- a/src/tagmanager/tm_parser.c
+++ b/src/tagmanager/tm_parser.c
@@ -511,6 +511,10 @@ static TMParserMapEntry map_POWERSHELL[] = {
 	{'v', tm_tag_variable_t},
 };
 
+static TMParserMapEntry map_GIBIANE[] = {
+	{'p', tm_tag_function_t},
+	{'v', tm_tag_variable_t},
+};
 
 typedef struct
 {
@@ -573,6 +577,7 @@ static TMParserMap parser_map[] = {
 	MAP_ENTRY(JSON),
 	MAP_ENTRY(ZEPHIR),
 	MAP_ENTRY(POWERSHELL),
+	MAP_ENTRY(GIBIANE),
 };
 /* make sure the parser map is consistent and complete */
 G_STATIC_ASSERT(G_N_ELEMENTS(parser_map) == TM_PARSER_COUNT);
diff --git a/src/tagmanager/tm_parser.h b/src/tagmanager/tm_parser.h
index db64a61f..38509e7f 100644
--- a/src/tagmanager/tm_parser.h
+++ b/src/tagmanager/tm_parser.h
@@ -109,6 +109,7 @@ enum
 	TM_PARSER_JSON,
 	TM_PARSER_ZEPHIR,
 	TM_PARSER_POWERSHELL,
+	TM_PARSER_GIBIANE,
 	TM_PARSER_COUNT
 };
 
diff --git a/src/tagmanager/tm_workspace.c b/src/tagmanager/tm_workspace.c
index 6b2ef82f..a66f8567 100644
--- a/src/tagmanager/tm_workspace.c
+++ b/src/tagmanager/tm_workspace.c
@@ -576,12 +576,15 @@ static gchar *pre_process_file(const gchar *cmd, const gchar *inf)
  @return TRUE on success, FALSE on failure.
 */
 gboolean tm_workspace_create_global_tags(const char *pre_process, const char **includes,
-	int includes_count, const char *tags_file, TMParserType lang)
+	int includes_count, const char *tags_file, TMParserType lang, gchar *pattern0)
 {
 	gboolean ret = FALSE;
 	TMSourceFile *source_file;
 	GList *includes_files;
-	gchar *temp_file = create_temp_file("tmp_XXXXXX.cpp");
+	GString *filename = g_string_new("tmp_XXXXXX");
+	filename = g_string_append(filename, pattern0+1);
+	gchar *temp_file = create_temp_file(filename->str);
+	g_string_free(filename, TRUE);
 
 	if (!temp_file)
 		return FALSE;
diff --git a/src/tagmanager/tm_workspace.h b/src/tagmanager/tm_workspace.h
index df586911..f8e74b6f 100644
--- a/src/tagmanager/tm_workspace.h
+++ b/src/tagmanager/tm_workspace.h
@@ -51,7 +51,7 @@ const TMWorkspace *tm_get_workspace(void);
 gboolean tm_workspace_load_global_tags(const char *tags_file, TMParserType mode);
 
 gboolean tm_workspace_create_global_tags(const char *pre_process, const char **includes,
-	int includes_count, const char *tags_file, TMParserType lang);
+	int includes_count, const char *tags_file, TMParserType lang, gchar *pattern0);
 
 GPtrArray *tm_workspace_find(const char *name, const char *scope, TMTagType type,
 	TMTagAttrType *attrs, TMParserType lang);
-- 
2.11.0

